Guidelines for annotating molecular carrier activity
Pathway Editor
The activity unit for a molecular carrier is:
●

MF: a molecular carrier 'enables' molecular carrier activity (GO:0140104) or a child

●

Context:
o

o

o

The relation between a transported molecule and its carrier is 'has input'. The
carrier and the small molecule are linked with the 'has output' relation, so that the
small molecule can be the input for the next reaction.
BP 'part of' the process in the molecule using the small molecule participates, or
'part of' regulation of the process, if the carrier is regulators (rate-limiting for the
execution of the process)
CC: 'occurs in' the cellular location where the activity takes place.

Example 1: LPS is carried to its receptor by CD14

Form Editor
The activity unit for a molecular carrier is:
●

MF: a molecular carrier 'enables' molecular carrier activity (GO:0140104) or a child

●

Context:
o

o

o

The relation between a transported molecule and its carrier is 'has input'. The
carrier and the small molecule are linked with the 'has output' relation, so that the
small molecule can be the input for the next reaction.
BP 'part of' the process in the molecule using the small molecule participates, or
'part of' regulation of the process, if the carrier is regulators (rate-limiting for the
execution of the process)
CC: 'occurs in' the cellular location where the activity takes place.

Differences between GO-CAM and standard
annotation for a molecular carrier activity
The same information is captured for the carrier activity and its context; however in the standard
annotations,it is not possible to capture the order of the reactions.

Review information
Review date: 2023-07-25
Reviewed by: Cristina Casals, Pasclae Gaudet, Patrick Masson

